@@ -21,8 +21,10 @@ import logging
 import os
 import pickle
 
+from base64 import b64decode
 from unicodedata import normalize
 
+from encuentro import utils
 from encuentro.ui import dialogs
 
 logger = logging.getLogger('encuentro.data')
@@ -65,16 +67,20 @@ class EpisodeData(object):
     # these is for the attributes to be here when unpickling old instances
     image_url = None
     downtype = None
+    image_data = None
+    subtitle = None
 
     def __init__(self, channel, section, title, duration, description,
                  episode_id, url, image_url, state=None, progress=None,
-                 filename=None, downtype=None, season=None):
+                 filename=None, downtype=None, season=None,
+                 image_data=None, subtitle=None):
         self.channel = channel
         self.section = section
         self.season = None if season is None else cgi.escape(season)
         self.title = cgi.escape(title)
         self.duration = duration
         self.description = description
+        self.subtitle = subtitle
         self.episode_id = episode_id
 
         # build a nice string to show in the GUI
@@ -87,6 +93,9 @@ class EpisodeData(object):
         self.url = str(url)
         self.image_url = str(image_url)
 
+        # image data is encoded in base64
+        self.image_data = None if image_data is None else b64decode(image_data)
+
         self.state = Status.none if state is None else state
         self.progress = progress
         self.filename = filename
@@ -109,7 +118,8 @@ class EpisodeData(object):
 
     def update(self, channel, section, title, duration, description,
                episode_id, url, image_url, state=None, progress=None,
-               filename=None, downtype=None, season=None):
+               filename=None, downtype=None, season=None,
+               image_data=None, subtitle=None):
         """Update the episode data."""
         self.channel = channel
         self.section = section
@@ -117,6 +127,7 @@ class EpisodeData(object):
         self.title = cgi.escape(title)
         self.duration = duration
         self.description = description
+        self.subtitle = subtitle
         self.episode_id = episode_id
 
         # build a nice string to show in the GUI
@@ -129,11 +140,17 @@ class EpisodeData(object):
         self.url = str(url)
         self.image_url = str(image_url)
 
+        # image data is encoded in base64
+        self.image_data = None if image_data is None else b64decode(image_data)
+
         self.state = Status.none if state is None else state
         self.progress = progress
         self.filename = filename
         self.downtype = downtype
 
+        # cache the processed title, overwritting what may be old from the past
+        self._normalized_title = prepare_to_filter(self.composed_title)
+
     def filter_params(self, text, only_downloaded):
         """Return the filtering params.
 
@@ -182,10 +199,10 @@ class ProgramsData(object):
     def merge(self, new_data, episodes_widget):
         """Merge new data to current programs data."""
         for d in new_data:
-            # v2 of json file
-            names = ['channel', 'section', 'title', 'duration', 'description',
-                     'episode_id', 'url', 'image_url', 'downtype', 'season']
-            values = dict((name, d[name]) for name in names)
+            names = ['channel', 'section', 'title', 'duration',
+                     'description', 'episode_id', 'url', 'image_url',
+                     'downtype', 'season', 'image_data', 'subtitle']
+            values = dict((name, d.get(name)) for name in names)
             episode_id = d['episode_id']
 
             try:
@@ -289,7 +306,5 @@ class ProgramsData(object):
     def save(self):
         """Save to disk."""
         to_save = (self.last_programs_version, self.data)
-        temp = self.filename + ".tmp"
-        with open(temp, 'wb') as fh:
+        with utils.SafeSaver(self.filename) as fh:
             pickle.dump(to_save, fh)
-        os.rename(temp, self.filename)
